@@ -38,8 +38,8 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK,);
 sub _dump_result($)
 {
     my $r=shift;
-    printf "result->err: %.18g\n", $r->{err};
-    printf "result->val: %.18g\n", $r->{val};
+    diag sprintf( "result->err: %.18g\n", $r->{err});
+    diag sprintf( "result->val: %.18g\n", $r->{val});
 }
 
 =head2 is_windows()
@@ -75,15 +75,15 @@ sub is_similar {
     $eps ||= 1e-8;
     if (ref $x eq 'ARRAY' && ref $y eq 'ARRAY') {
         if ( $#$x != $#$y ){
-            warn "is_similar(): items differ in length, $#$x != $#$y !!!";
+            diag "is_similar(): items differ in length, $#$x != $#$y !!!";
             return 0;
         } else {
             map { 
                     my $delta = (gsl_isnan($x->[$_]) or gsl_isnan($y->[$_])) ? gsl_nan() : abs($x->[$_] - $y->[$_]);
                     if($delta > $eps){
-                        warn "\n\tElements start differing at index $_, delta = $delta\n";
-                        warn qq{\t\t\$x->[$_] = } . $x->[$_] . "\n";
-                        warn qq{\t\t\$y->[$_] = } . $y->[$_] . "\n";
+                        diag "\n\tElements start differing at index $_, delta = $delta\n";
+                        diag qq{\t\t\$x->[$_] = } . $x->[$_] . "\n";
+                        diag qq{\t\t\$y->[$_] = } . $y->[$_] . "\n";
                         return 0;
                     }
                 } (0..$#$x);
@@ -94,7 +94,7 @@ sub is_similar {
                $similarity_function->($x,$y) <= $eps ? return 1 : return 0;
         } elsif( defined $x && defined $y) { 
             my $delta = (gsl_isnan($x) or gsl_isnan($y)) ? gsl_nan() : abs($x-$y);
-            $delta > $eps ? warn qq{\t\t\$x=$x\n\t\t\$y=$y\n\t\tdelta=$delta\n} && return 0 : return 1;
+            $delta > $eps ? diag qq{\t\t\$x=$x\n\t\t\$y=$y\n\t\tdelta=$delta\n} && return 0 : return 1;
         } else {
             return 0;
         }
@@ -104,13 +104,16 @@ sub is_similar {
 # this is a huge hack
 sub verify_results
 {
-    my ($results,$class) = @_;
-    # GSL uses a factor of 100 
-    my $factor   = 20; 
-    my $eps      = 2048*$Math::GSL::Machine::GSL_DBL_EPSILON; # TOL3
+    my ($results,$class, $eps) = @_;
+    # GSL uses a factor of 100
+    my $factor   = 100;
     my ($x,$res);
+
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
+    # If no epsilon is passed in, default to TOL3 from the GSL test suite
+    $eps    ||= 2048*$Math::GSL::Machine::GSL_DBL_EPSILON; # TOL3
+
     croak "Usage: verify_results(%results, \$class)" unless $class;
     while (my($code,$expected)=each %$results){
         my $r        = Math::GSL::SF::gsl_sf_result_struct->new;
@@ -127,10 +130,10 @@ sub verify_results
 
             if ($ENV{DEBUG} ){
                 _dump_result($r);
-                print "got $code = $x\n";
-                printf "expected   : %.18g\n", $expected ;
-                printf "difference : %.18g\n", $res;
-                printf "unexpected error of %.18g\n", $res-$eps if ($res-$eps>0);
+                #print "got $code = $x\n";
+                diag sprintf("expected   : %.18g\n", $expected);
+                diag sprintf("difference : %.18g\n", $res);
+                diag sprintf("unexpected error of %.18g\n", $res-$eps) if ($res-$eps>0);
             }
             if (gsl_isnan($x)) {
                     ok( gsl_isnan($expected), sprintf("'$expected'?='$x' (%16b ?= %16b)", $expected, $x) );
